Package: fastml / 3.1-3

spelling.patch Patch series | download
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
Author: Andreas Tille <tille@debian.org>
Last-Update: Thu, 19 Nov 2015 14:47:11 +0100
Description: Fix some spelling issues

--- a/libs/phylogeny/numRec.cpp
+++ b/libs/phylogeny/numRec.cpp
@@ -134,7 +134,7 @@ int MyJacobi(VVdouble &Insym, VVdouble &
 		} // end of for (ip = ...
 	} // end of for (i = 0; i< MaxNumberOfSweeps ; ++i) {
 	vector<string> err;
-	err.push_back("problems in function MyJacobi. more than MaxNumberOfSweeps were necesary.");
+	err.push_back("problems in function MyJacobi. more than MaxNumberOfSweeps were necessary.");
 	errorMsg::reportError(err);
 	
 	return -1;
--- a/programs/fastml/bb_options_list.h
+++ b/programs/fastml/bb_options_list.h
@@ -9,7 +9,7 @@ static string usage() {
 	tmp +=" |-t tree input file                                                          |\n";
 	tmp +=" |   (if tree is not given, a neighbor joining tree is computed).             |\n";
 	tmp +=" |-g Assume among site rate variation model (Gamma) [By default the program   |\n";
-	tmp +=" |   will assume an homogenous model. very fast, but less accurate!]          |\n";
+	tmp +=" |   will assume an homogeneous model. very fast, but less accurate!]         |\n";
 	tmp += "|-m     model name                                                           |\n";
 	tmp += "|-mj    [JTT]                                                                |\n";
 	tmp += "|-ml    LG                                                                   |\n";
@@ -36,7 +36,7 @@ static string usage() {
 	tmp +=" |     -qm = MOLPHY, -qs = MASE, -qp = PHLIYP, -qn = Nexus                    |\n";
 	tmp +=" +----------------------------------------------------------------------------+\n";         
 	tmp +=" |Advances options:                                                           |\n";
-	tmp +=" |-a   Treshold for computing again marginal probabilities [0.9]              |\n";
+	tmp +=" |-a   Threshold for computing again marginal probabilities [0.9]             |\n";
 	tmp +=" |-b   Do not optimize branch lengths on starting tree                        |\n";
 	tmp +=" |     [by default branches and alpha are ML optimized from the data]         |\n";
 	tmp +=" |-c   number of discrete Gamma categories for the gamma distribution [8]     |\n";
--- a/programs/gainLoss/computeCorrelations.cpp
+++ b/programs/gainLoss/computeCorrelations.cpp
@@ -137,7 +137,7 @@ void computeCorrelations::runComputeCorr
 		numOfpositionsIn_B = _expChanges_PosNodeXY.size(); // if B is not given, it's copy
 
 	if(_isTwoSetsOfInputForCorrelation)
-		LOGnOUT(3, <<"NOTE: Two seperate dataset input.\n Compute correl for selectedSites="<<numOfSitesSelected<<" subset of A="<<numOfpositionsIn_A<<" against B="<<numOfpositionsIn_B<<endl);
+		LOGnOUT(3, <<"NOTE: Two separate dataset input.\n Compute correl for selectedSites="<<numOfSitesSelected<<" subset of A="<<numOfpositionsIn_A<<" against B="<<numOfpositionsIn_B<<endl);
 		
 	//// Mapping vectors
 	LOGnOUT(4, <<"Fill events vectors..."<<endl);
--- a/programs/gainLoss/gainLoss.cpp
+++ b/programs/gainLoss/gainLoss.cpp
@@ -4525,7 +4525,7 @@ void gainLoss::startSimultePosteriorExpe
 	LOGnOUT(4,<<(gainLossOptions::_userAlphaLoss/gainLossOptions::_userBetaLoss) /  (gainLossOptions::_userAlphaGain/gainLossOptions::_userBetaGain)<<endl);
 	if(!gainLossOptions::_isRootFreqEQstationaryInSimulations){
 		if(gainLossOptions::_initRootFreqAtRandPointsInSimPostExpEachPos)
-			LOGnOUT(4,<<"Root(1) freq is sampled seperatly for each pos"<<endl)
+			LOGnOUT(4,<<"Root(1) freq is sampled separately for each pos"<<endl)
 		else
 		LOGnOUT(4,<<"Root(1) freq is sampled once for the entire replication (sim all positions)"<<endl)
 		if(isComputeEmpiricalCorrection 
--- a/libs/phylogeny/likeDistfixRoot.cpp
+++ b/libs/phylogeny/likeDistfixRoot.cpp
@@ -145,10 +145,10 @@ MDOUBLE likeDistfixRoot::evalLogLikeliho
 //						const sequence& s2,
 //						const vector<MDOUBLE>  * weights,
 //						MDOUBLE* score) const {
-//    // only in the case of homogenous model - work through pairwise EM like
+//    // only in the case of homogeneous model - work through pairwise EM like
 //    countTableComponentGam ctc;
 //    if (_sp.categories() != 1) {
-//	errorMsg::reportError("this function only work for homogenous model.");
+//	errorMsg::reportError("this function only work for homogeneous model.");
 //    }
 //    ctc.countTableComponentAllocatePlace(s1.getAlphabet()->size(),1);
 //    for (int i=0; i<s1.seqLen(); ++i) {
--- a/libs/phylogeny/likeDist.cpp
+++ b/libs/phylogeny/likeDist.cpp
@@ -145,10 +145,10 @@ MDOUBLE likeDist::giveDistanceThroughCTC
 						const sequence& s2,
 						const vector<MDOUBLE>  * weights,
 						MDOUBLE* score) const {
     // only in the case of homogenous model - work through pairwise EM like
     countTableComponentGam ctc;
     if (_sp.categories() != 1) {
-	errorMsg::reportError("this function only work for homogenous model.");
+	errorMsg::reportError("this function only work for homogeneous model.");
     }
     ctc.countTableComponentAllocatePlace(s1.getAlphabet()->size(),1);
     for (int i=0; i<s1.seqLen(); ++i) {
@@ -145,10 +145,10 @@ MDOUBLE likeDist::giveDistanceThroughCTC
 						const vector<MDOUBLE>  * weights,
 						MDOUBLE* score) const {
-    // only in the case of homogenous model - work through pairwise EM like
+    // only in the case of homogeneous model - work through pairwise EM like
     countTableComponentGam ctc;
     if (_sp.categories() != 1) {
--- a/programs/fastml/mainbb.cpp
+++ b/programs/fastml/mainbb.cpp
@@ -98,7 +98,7 @@ void mainbb::getStartingEvolTreeTopology
 
 void mainbb::getStartingNJtreeNjMLdis() {
 	// note that here ALWAYS, the ML distances are computed using
 	// an homogenous rate distribution.
 	uniDistribution lUni;
 //	const pijAccelerator* lpijAcc = _sp->getPijAccelerator();// note this is just a copy of the pointer.
 	const pijAccelerator* lpijAcc = _spVec[0].getPijAccelerator();// note this is just a copy of the pointer.
@@ -248,9 +248,9 @@ void mainbb::getStartingStochasticProces
 	int numberOfCategories = _options->gammaCategies;
 	MDOUBLE alpha = _options->gammaPar;
 	if (_options->distributionName == bb_options::hom) {
-		numberOfCategories = 1; // forcing homogenous model.
+		numberOfCategories = 1; // forcing homogeneous model.
 		alpha = 1.0;
-		cout<<"Using homogenous model (no among site rate variation)"<<endl;
+		cout<<"Using homogeneous model (no among site rate variation)"<<endl;
 	} else {
 		cout<<"Using a Gamma model with: "<<numberOfCategories<<" discrete categories "<<endl;
 	}
@@ -98,7 +98,7 @@ void mainbb::getStartingEvolTreeTopology
 void mainbb::getStartingNJtreeNjMLdis() {
 	// note that here ALWAYS, the ML distances are computed using
-	// an homogenous rate distribution.
+	// an homogeneous rate distribution.
 	uniDistribution lUni;
 //	const pijAccelerator* lpijAcc = _sp->getPijAccelerator();// note this is just a copy of the pointer.